@@ -108,6 +108,8 @@ long as said assignments conform with the specification above.
 .. data:: sge.s.escape
 .. data:: sge.s.euro
 .. data:: sge.s.exclamation
+.. data:: sge.s.extra1
+.. data:: sge.s.extra2
 .. data:: sge.s.f0
 .. data:: sge.s.f1
 .. data:: sge.s.f2
@@ -133,11 +135,13 @@ long as said assignments conform with the specification above.
 .. data:: sge.s.hat_left
 .. data:: sge.s.hat_right
 .. data:: sge.s.hat_up
+.. data:: sge.s.hexagonal
 .. data:: sge.s.home
 .. data:: sge.s.hyphen
 .. data:: sge.s.insert
 .. data:: sge.s.iris_in
 .. data:: sge.s.iris_out
+.. data:: sge.s.isohex
 .. data:: sge.s.isometric
 .. data:: sge.s.kp_0
 .. data:: sge.s.kp_1
@@ -386,6 +390,8 @@ wheel_up = "wheel_up"
 wheel_down = "wheel_down"
 wheel_left = "wheel_left"
 wheel_right = "wheel_right"
+extra1 = "extra1"
+extra2 = "extra2"
 
 # Joystick input types
 # "axis+" and "axis-" unfortunately must be excluded.
@@ -419,6 +425,8 @@ iris_in = "iris_in"
 iris_out = "iris_out"
 
 # Tile grids
+hexagonal = "hexagonal"
+isohex = "isohex"
 isometric = "isometric"
 orthogonal = "orthogonal"
 
